<img alt="MergeDB" src="docs/media/MergeDB-color.png" width="50%" height="50%">

[![Documentation Status](https://readthedocs.org/projects/mergedb/badge/?version=latest)](https://mergedb.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/graysonhead/mergedb.svg?branch=master)](https://travis-ci.com/graysonhead/mergedb)


# MergeDB

MergeDB is a YAML based hierarchical database with a customizable rule-based deep merge system. 

It allows you to smash YAML files together with precision, enabling you to generate YAML for automation tools without 
repeating yourself.

## Examples

Please see the docs, or the examples directory to see how to set up your MergeDB directory

## Quickstart